unit TestWebCylinderBooleanU;

interface

uses
  WEBLib.UnitTesting.Classes, System.Classes, web, js, WEBLib.TMSFNCJSONReader,
  WEBLib.TMSFNCPersistence;

type
  TCylinder = class (TPersistent) //abstract
  strict private
    FCylinderNumber: integer;
    FFired: boolean;
  public
    constructor Create;
  published
    property CylinderNumber: integer read FCylinderNumber write FCylinderNumber;
    property Fired: boolean read FFired write FFired;
  end;

  TOddCylinder = class(TCylinder);
  TEvenCylinder = class(TCylinder);
  TTallCylinder = class(TCylinder);
  TShortCylinder = class(TCylinder);

{$M+}

  // Example of a class containing methods with unit tests.
  // Mark it with [TestFixture] custom attribute and register with
  // TTMSWEBUnitTestingRunner as shown below.
  [TestFixture]
  TMyTestClassUnit3 = class(TObject)
  private
  FTestResult : boolean;
    procedure RegisterJSONClasses;
  published
    // Example method that contains a unit test. Annotate it with [Test]
    [Test]
    procedure TestCylinderFive;
    [Test]
    procedure TestCylinderSixtySix;
    [Test]
    procedure TestEvenCylinder;
    [Test]
    procedure TestOddCylinder;
    [Test]
    procedure TestShortCylinder;
    [Test]
    procedure TestTallCylinder;
  end;
{$M-}

implementation

uses
  SysUtils;

{ TMyTestClassUnit3 }

{ TCylinder }

constructor TCylinder.Create;
begin
  FFired := False;
  FCylinderNumber := 0;
end;

{ TMyTestClassUnit3 }

procedure TMyTestClassUnit3.RegisterJSONClasses;
begin
  RegisterClass(TCylinder);
  RegisterClass(TOddCylinder);
  RegisterClass(TEvenCylinder);
  RegisterClass(TTallCylinder);
  RegisterClass(TShortCylinder);
end;

procedure TMyTestClassUnit3.TestCylinderFive;
var
  cyl, restore: TCylinder;
  json: string;
begin
 RegisterJSONClasses;
  cyl := TCylinder.Create;
  restore := TCylinder.Create;
  try
  FTestResult := false;
    try
      cyl.CylinderNumber := 5;
      Assert.AreEqual(cyl.Fired, restore.Fired, 'check fired before restore b 2 b');
      cyl.Fired := true;
      Assert.AreNotEqual(cyl.Fired, restore.Fired, 'check fired before restore b 2 b');
      json := TTMSFNCObjectPersistence.SaveObjectToString(cyl);
      TTMSFNCObjectPersistence.LoadObjectFromString(restore, json);
      Assert.IsTrue(json.Length > 0, 'Json length check');
      Assert.AreEqual(cyl.CylinderNumber, restore.CylinderNumber, 'check number');
      // added to debug boolean
      if restore.Fired then
        Console.log('restore has been fired')
      else
        Console.log('restore ready to fire');
      // fails trying to compare true to 1
      Assert.AreEqual(cyl.Fired, restore.Fired, 'check fired b 2 b');
      // fails true <> 1
      Assert.IsTrue((cyl.Fired = restore.Fired), 'check fired eq is true');
      // this works and the 2 booleans
      Assert.IsTrue((cyl.Fired) and (restore.Fired), 'check fired and is true');
      FTestResult := true;
    except
      on E: Exception do
        Console.log('Failure in CylinderFive Low e:' + E.Message)
      else
        Console.log('Failure in CylinderFive Low js:' + String(js.JSExceptValue))
    end;
        Assert.IsTrue(FTestResult, 'Test Completion Status');
  finally
    cyl.Free;
    restore.Free;
  end;
end;

procedure TMyTestClassUnit3.TestCylinderSixtySix;
var
  cyl, restore: TCylinder;
  json: string;
begin
 RegisterJSONClasses;
  cyl := TCylinder.Create;
  restore := TCylinder.Create;
  try
  FTestResult := false;
    try
      cyl.CylinderNumber := 512;
      Assert.AreEqual(cyl.Fired, restore.Fired, 'check fired before restore b 2 b');
      cyl.Fired := true;
      Assert.AreNotEqual(cyl.Fired, restore.Fired, 'check fired before restore b 2 b');
      json := TTMSFNCObjectPersistence.SaveObjectToString(cyl);
      TTMSFNCObjectPersistence.LoadObjectFromString(restore, json);
      Assert.IsTrue(json.Length > 0, 'Json length check');
      Assert.AreEqual(cyl.CylinderNumber, restore.CylinderNumber, 'check number');
      // added to debug boolean
      if restore.Fired then
        Console.log('restore has been fired')
      else
        Console.log('restore ready to fire');
      // fails trying to compare true to 1
      Assert.AreEqual(cyl.Fired, restore.Fired, 'check fired b 2 b');
      // fails true <> 1
      Assert.IsTrue((cyl.Fired = restore.Fired), 'check fired eq is true');
      // this works and the 2 booleans
      Assert.IsTrue((cyl.Fired) and (restore.Fired), 'check fired and is true');
      FTestResult := true;
    except
      on E: Exception do
        Console.log('Failure in Cylinder66 Low e:' + E.Message)
      else
        Console.log('Failure in Cylinder66 Low js:' + String(js.JSExceptValue))
    end;
        Assert.IsTrue(FTestResult, 'Test Completion Status');
  finally
    cyl.Free;
    restore.Free;
  end;
end;

procedure TMyTestClassUnit3.TestEvenCylinder;
var
  cyl, restore: TEvenCylinder;
  json: string;
begin
 RegisterJSONClasses;
  cyl := TEvenCylinder.Create;
  restore := TEvenCylinder.Create;
  try
    FTestResult := false;
    try
      cyl.CylinderNumber := 5;
      Assert.AreEqual(cyl.Fired, restore.Fired, 'check fired before restore b 2 b');
      cyl.Fired := true;
      Assert.AreNotEqual(cyl.Fired, restore.Fired, 'check fired before restore b 2 b');
      json := TTMSFNCObjectPersistence.SaveObjectToString(cyl);
      TTMSFNCObjectPersistence.LoadObjectFromString(restore, json);
      Assert.IsTrue(json.Length > 0, 'Json length check');
      Assert.AreEqual(cyl.CylinderNumber, restore.CylinderNumber, 'check number');
      // added to debug boolean
      if restore.Fired then
        Console.log('restore has been fired')
      else
        Console.log('restore ready to fire');
      // fails trying to compare true to 1
      Assert.AreEqual(cyl.Fired, restore.Fired, 'check fired b 2 b');
      // fails true <> 1
      Assert.IsTrue((cyl.Fired = restore.Fired), 'check fired eq is true');
      // this works and the 2 booleans
      Assert.IsTrue((cyl.Fired) and (restore.Fired), 'check fired and is true');
      FTestResult := true;
    except
      on E: Exception do
        Console.log('Failure in EvenCylinder Low e:' + E.Message)
      else
        Console.log('Failure in EvenCylinder Low js:' + String(js.JSExceptValue))
    end;
        Assert.IsTrue(FTestResult, 'Test Completion Status');
  finally
    cyl.Free;
    restore.Free;
  end;

end;

procedure TMyTestClassUnit3.TestOddCylinder;
var
  cyl, restore: TOddCylinder;
  json: string;
begin
  RegisterJSONClasses;
  cyl := TOddCylinder.Create;
  restore := TOddCylinder.Create;
  try
    FTestResult := false;
    try
      cyl.CylinderNumber := 5;
      Assert.AreEqual(cyl.Fired, restore.Fired, 'check fired before restore b 2 b');
      cyl.Fired := true;
      Assert.AreNotEqual(cyl.Fired, restore.Fired, 'check fired before restore b 2 b');
      json := TTMSFNCObjectPersistence.SaveObjectToString(cyl);
      TTMSFNCObjectPersistence.LoadObjectFromString(restore, json);
      Assert.IsTrue(json.Length > 0, 'Json length check');
      Assert.AreEqual(cyl.CylinderNumber, restore.CylinderNumber, 'check number');
      // added to debug boolean
      if restore.Fired then
        Console.log('restore has been fired')
      else
        Console.log('restore ready to fire');
      // fails trying to compare true to 1
      Assert.AreEqual(cyl.Fired, restore.Fired, 'check fired b 2 b');
      // fails true <> 1
      Assert.IsTrue((cyl.Fired = restore.Fired), 'check fired eq is true');
      // this works and the 2 booleans
      Assert.IsTrue((cyl.Fired) and (restore.Fired), 'check fired and is true');
      FTestResult := true;
    except
      on E: Exception do
        Console.log('Failure in OddCylinder Low e:' + E.Message)
      else
        Console.log('Failure in OddCylinder Low js:' + String(js.JSExceptValue))
    end;
        Assert.IsTrue(FTestResult, 'Test Completion Status');
  finally
    cyl.Free;
    restore.Free;
  end;

end;

procedure TMyTestClassUnit3.TestShortCylinder;
var
  cyl, restore: TShortCylinder;
  json: string;
begin
  RegisterJSONClasses;
  cyl := TShortCylinder.Create;
  restore := TShortCylinder.Create;
  try
    FTestResult := false;
    try
      cyl.CylinderNumber := 5;
      Assert.AreEqual(cyl.Fired, restore.Fired, 'check fired before restore b 2 b');
      cyl.Fired := true;
      Assert.AreNotEqual(cyl.Fired, restore.Fired, 'check fired before restore b 2 b');
      json := TTMSFNCObjectPersistence.SaveObjectToString(cyl);
      TTMSFNCObjectPersistence.LoadObjectFromString(restore, json);
      Assert.IsTrue(json.Length > 0, 'Json length check');
      Assert.AreEqual(cyl.CylinderNumber, restore.CylinderNumber, 'check number');
      // added to debug boolean
      if restore.Fired then
        Console.log('restore has been fired')
      else
        Console.log('restore ready to fire');
      // fails trying to compare true to 1
      Assert.AreEqual(cyl.Fired, restore.Fired, 'check fired b 2 b');
      // fails true <> 1
      Assert.IsTrue((cyl.Fired = restore.Fired), 'check fired eq is true');
      // this works and the 2 booleans
      Assert.IsTrue((cyl.Fired) and (restore.Fired), 'check fired and is true');
      FTestResult := true;
    except
      on E: Exception do
        Console.log('Failure in ShortCylinder Low e:' + E.Message)
      else
        Console.log('Failure in ShortCylinder Low js:' + String(js.JSExceptValue))
    end;
    Assert.IsTrue(FTestResult, 'Test Completion Status');
  finally
    cyl.Free;
    restore.Free;
  end;

end;

procedure TMyTestClassUnit3.TestTallCylinder;
var
  cyl, restore: TTallCylinder;
  json: string;
begin
  RegisterJSONClasses;
  cyl := TTallCylinder.Create;
  restore := TTallCylinder.Create;
  try
    FTestResult := false;
    try
      cyl.CylinderNumber := 5;
      Assert.AreEqual(cyl.Fired, restore.Fired, 'check fired before restore b 2 b');
      cyl.Fired := true;
      Assert.AreNotEqual(cyl.Fired, restore.Fired, 'check fired before restore b 2 b');
      json := TTMSFNCObjectPersistence.SaveObjectToString(cyl);
      TTMSFNCObjectPersistence.LoadObjectFromString(restore, json);
      Assert.IsTrue(json.Length > 0, 'Json length check');
      Assert.AreEqual(cyl.CylinderNumber, restore.CylinderNumber, 'check number');
      // added to debug boolean
      if restore.Fired then
        Console.log('restore has been fired')
      else
        Console.log('restore ready to fire');
      // fails trying to compare true to 1
      Assert.AreEqual(cyl.Fired, restore.Fired, 'check fired b 2 b');
      // fails true <> 1
      Assert.IsTrue((cyl.Fired = restore.Fired), 'check fired eq is true');
      // this works and the 2 booleans
      Assert.IsTrue((cyl.Fired) and (restore.Fired), 'check fired and is true');
      FTestResult := true;
    except
      on E: Exception do
        Console.log('Failure in TallCylinder Low e:' + E.Message)
      else
        Console.log('Failure in TallCylinder Low js:' + String(js.JSExceptValue))
    end;
    Assert.IsTrue(FTestResult, 'Test Completion Status');
  finally
    cyl.Free;
    restore.Free;
  end;
end;

initialization

// Registration of the test classes.
TTMSWEBUnitTestingRunner.RegisterClass(TMyTestClassUnit3);

end.
